@@ -1,21 +1,22 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -42,11 +43,23 @@ public:
 
 	void startDocument() {}
 	void startSubDocument() {}
-	void insertCharacter(uint16_t /* character */) { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void insertExtendedCharacter(uint8_t /* extendedCharacter */) { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void insertTab() { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void insertEOL() { if (!isUndoOn()) m_currentPageHasContent = true; }
- 	void insertBreak(uint8_t breakType);
+	void insertCharacter(uint32_t /* character */)
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
+	void insertExtendedCharacter(uint8_t /* extendedCharacter */)
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
+	void insertTab()
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
+	void insertEOL()
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
+	void insertBreak(uint8_t breakType);
 	void insertNote(WPXNoteType /* noteType */, WP1SubDocument * /* subDocument */) {}
 	void attributeChange(bool /* isOn */, uint8_t /* attribute */) {}
 	void fontPointSize(uint8_t /* pointSize */) {}
@@ -54,10 +67,16 @@ public:
 	void marginReset(uint16_t leftMargin, uint16_t rightMargin);
 	void topMarginSet(uint16_t topMargin);
 	void bottomMarginSet(uint16_t bottomMargin);
-	void leftIndent(uint16_t /* leftMarginOffset */) { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void leftRightIndent(uint16_t /* leftRightMarginOffset */) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void leftIndent(uint16_t /* leftMarginOffset */)
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
+	void leftRightIndent(uint16_t /* leftRightMarginOffset */)
+	{
+		if (!isUndoOn()) m_currentPageHasContent = true;
+	}
 	void leftMarginRelease(uint16_t /* release */) {}
-	void setTabs(const std::vector<WPXTabStop>& /* tabStops */) {}
+	void setTabs(const std::vector<WPXTabStop> & /* tabStops */) {}
 	void headerFooterGroup(uint8_t headerFooterDefinition, WP1SubDocument *subDocument);
 	void suppressPageCharacteristics(uint8_t suppressCode);
 	void justificationChange(uint8_t /* justification */) {}
@@ -83,3 +102,4 @@ private:
 };
 
 #endif /* WP1STYLESLISTENER_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
