@@ -1,20 +1,21 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,8 +27,10 @@
 #ifndef WP6FILESTRUCTURE_H
 #define WP6FILESTRUCTURE_H
 
+#include "libwpd_internal.h"
+
 // size of the fixed length functiongroups 0xF0 to 0xFF
-extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
+extern uint8_t WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 
 /* standard sizes */
 #define WP6_NUM_LIST_LEVELS 8
@@ -550,3 +553,4 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_UNDO_GROUP_VALID_TEXT_END 3
 
 #endif /* WP6FILESTRUCTURE_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
