@@ -1,21 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -36,9 +36,13 @@ WP6PrefixData::WP6PrefixData(WPXInputStream *input, WPXEncryption *encryption, c
 	m_prefixDataPacketTypeHash(),
 	m_defaultInitialFontPID((-1))
 {
+	if (!numPrefixIndices)
+	{
+		WPD_DEBUG_MSG(("WordPerfect: constructing called without any prefix\n"));
+		return;
+	}
 	uint16_t i;
-
-	WP6PrefixIndice **prefixIndiceArray = new WP6PrefixIndice *[(numPrefixIndices-1)];
+	WP6PrefixIndice **prefixIndiceArray = new WP6PrefixIndice *[size_t(numPrefixIndices-1)];
 	for (i=1; i<numPrefixIndices; i++)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: constructing prefix indice 0x%x\n", i));
@@ -68,7 +72,7 @@ WP6PrefixData::WP6PrefixData(WPXInputStream *input, WPXEncryption *encryption, c
 WP6PrefixData::~WP6PrefixData()
 {
 	DPH::iterator pos;
-	for (pos = m_prefixDataPacketHash.begin(); pos!=m_prefixDataPacketHash.end(); pos++)
+	for (pos = m_prefixDataPacketHash.begin(); pos!=m_prefixDataPacketHash.end(); ++pos)
 	{
 		delete(pos->second);
 	}
