@@ -1,26 +1,27 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * For minor contributions see the git repository.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -29,10 +30,10 @@
 #include "WP6Listener.h"
 #include "libwpd_internal.h"
 
-WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, uint8_t groupID)
+WP6SingleByteFunction *WP6SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, WPXEncryption * /* encryption */, uint8_t groupID)
 {
 
-	switch (groupID) 
+	switch (groupID)
 	{
 	case WP6_TOP_SOFT_EOL:
 	case WP6_TOP_SOFT_EOL_AT_EOC:
@@ -45,7 +46,7 @@ WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXIn
 
 	case WP6_TOP_SOFT_HYPHEN_IN_LINE:
 	case WP6_TOP_SOFT_HYPHEN_AT_EOL:
-		return new WP6SoftHyphenFunction();		
+		return new WP6SoftHyphenFunction();
 
 	case WP6_TOP_HARD_HYPHEN:
 		return new WP6HyphenFunction();
@@ -64,7 +65,7 @@ WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXIn
 		return new WP6TableOffFunction();
 
 	case WP6_TOP_TABLE_OFF_AT_EOC_AT_EOP:
-		return new WP6TableOffAtSoftEOPFunction();			    
+		return new WP6TableOffAtSoftEOPFunction();
 
 	case WP6_TOP_TABLE_ROW_AT_EOC:
 	case WP6_TOP_TABLE_ROW:
@@ -93,7 +94,7 @@ WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXIn
 	case WP6_TOP_DELETABLE_HARD_EOP:
 		return new WP6EOPFunction();
 
-	// Add the remaining cases here
+		// Add the remaining cases here
 	default:
 		// should not happen
 		return 0;
@@ -102,17 +103,17 @@ WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXIn
 
 void WP6SpaceFunction::parse(WP6Listener *listener)
 {
-	listener->insertCharacter((uint16_t) ' ');
+	listener->insertCharacter((uint32_t) ' ');
 }
 
 void WP6HardSpaceFunction::parse(WP6Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xa0);
+	listener->insertCharacter((uint32_t) 0xa0);
 }
 
 void WP6SoftHyphenFunction::parse(WP6Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xad);
+	listener->insertCharacter((uint32_t) 0xad);
 }
 
 void WP6EOLFunction::parse(WP6Listener *listener)
@@ -137,7 +138,7 @@ void WP6SoftEOPFunction::parse(WP6Listener *listener)
 
 void WP6HyphenFunction::parse(WP6Listener *listener)
 {
-	listener->insertCharacter((uint16_t) '-');
+	listener->insertCharacter((uint32_t) '-');
 }
 
 void WP6TableRowFunction::parse(WP6Listener *listener)
@@ -197,3 +198,4 @@ void WP6TableRowAtEOCFunction::parse(WP6Listener *listener)
 	listener->insertBreak(WPX_COLUMN_BREAK);
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
